import pandas as pd
import networkx as nx
import matplotlib
import tkinter as tk
from tkinter import ttk

matplotlib.use('TkAgg')
from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
from matplotlib.figure import Figure
from video_game import VideoGame
import matplotlib.pyplot as plt

class Network_UI(tk.Tk):
    def __init__(self, video_game: VideoGame):
        super().__init__()  
        self.title("Game Genre Graph")
        self.G = nx.Graph()
        self.video_game = video_game
        self.genres = set(self.video_game.video_game_df['Genre'])

        self.genre1_var = tk.StringVar(master=self)

        self.genre2_var = tk.StringVar(master=self)
        
        self.init_component()

    def init_component(self):
        option_frame = tk.LabelFrame(self, text="Option")
        select_frame = tk.Frame(option_frame)

        genre1_label = tk.Label(select_frame, text="Select genre 1:")
        self.genre1_combobox = ttk.Combobox(select_frame, textvariable=self.genre1_var, state="readonly")
        self.genre1_combobox['values'] = list(self.genres)
        
        genre2_label = tk.Label(select_frame, text="Select genre 2:")
        self.genre2_combobox = ttk.Combobox(select_frame, textvariable=self.genre2_var, state="readonly")
        self.genre2_combobox['values'] = list(self.genres)
        
        find_path_button = tk.Button(select_frame, text="Find Shortest Path", command=self.find_shortest_path)

        option_frame.grid(row=0, column=0, sticky="news")
        select_frame.grid(row=0, column=0)

        genre1_label.grid(row=1, column=0)
        self.genre1_combobox.grid(row=2, column=0)

        genre2_label.grid(row=3, column=0)
        self.genre2_combobox.grid(row=4, column=0)

        find_path_button.grid(row=5, column=0)

        self.create_graph()
        
    def create_graph(self):
        print("Creating graph...")
        for genre1 in self.genres:
            for genre2 in self.genres:
                if genre1 != genre2:
                    publishers1 = set(self.video_game.video_game_df[self.video_game.video_game_df['Genre']==genre1]['Publisher'])
                    publishers2 = set(self.video_game.video_game_df[self.video_game.video_game_df['Genre']==genre2]['Publisher'])
                    shared_publishers = len(publishers1.intersection(publishers2))
                    if shared_publishers > 0:
                        self.G.add_edge(genre1, genre2, weight=shared_publishers)
        print("Plotting graph...")
        self.pos = nx.spring_layout(self.G)
        nx.draw_networkx(self.G, self.pos, with_labels=True, node_color='lightblue', node_size=1000, font_size=10, font_weight='bold')
        labels = nx.get_edge_attributes(self.G,'weight')
        nx.draw_networkx_edge_labels(self.G, self.pos, edge_labels=labels, font_size=8)
        plt.show()
        
    def find_shortest_path(self):
        #reset graph
        plt.clf()
        self.create_graph()
        genre1 = self.genre1_var.get()
        genre2 = self.genre2_var.get()
        # genre1 = 'Fighting'
        # genre2 = 'Sports'
        print("a")
        print(f"genre1:{genre1}, gen2:{genre2}")
        path = nx.shortest_path(self.G, genre1, genre2, weight='weight')
        edges = list(zip(path, path[1:]))
        nx.draw_networkx_edges(self.G, self.pos, edgelist=edges, edge_color='red', width=5)
        plt.show()
        
    def run(self):
        self.mainloop()

