import tkinter as tk
from tkinter import filedialog
import matplotlib

matplotlib.use('TkAgg')
from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
from matplotlib.figure import Figure
from video_game import VideoGame


class PageTwo(tk.Tk):
    def __init__(self, video_game: VideoGame):
        super().__init__()
        self.title("Video Game")
        self.video_game = video_game

        self.init_component()
        self.plot_graph(self.video_game.year[0])

    def init_component(self):
        self.frame_option = tk.LabelFrame(self, text="Select Year")

        slider_year = tk.Scale(self.frame_option, from_=self.video_game.year[0], to=self.video_game.year[-1],
                               orient=tk.HORIZONTAL, command=self.plot_graph)

        btn_quit = tk.Button(self.frame_option, text="QUIT", command=self.destroy)
        save_button = tk.Button(self.frame_option, text="SAVE", command=self.save_graph)
        self.bind('<s>',lambda event: self.save_graph())

        slider_year.grid(row=0, column=0, sticky="EW", padx=5)
        self.frame_option.grid(row=0, column=0, sticky="news")
        btn_quit.grid(row=0, column=2, padx=5)
        save_button.grid(row=0, column=1, padx=5)

        self.fig = Figure()
        self.axes = self.fig.add_subplot()
        self.fig_canvas = FigureCanvasTkAgg(self.fig, master=self)
        self.fig_canvas.get_tk_widget().grid(row=1, column=0, sticky="NEWS", padx=5, pady=5)

        self.frame_option.columnconfigure(0, weight=1)
        self.columnconfigure(0, weight=1)
        self.rowconfigure(1, weight=1)

    def plot_graph(self, year):
        self.axes.clear()
        graph = self.video_game.plot_pie(year, self.axes)
        self.fig_canvas.draw()

    def save_graph(self):
        file = filedialog.asksaveasfilename(title='Save File', filetypes=(("PNG file", "*.png"),))
        if file != "":
            self.fig.get_figure().savefig(file)

    def run(self):
        self.mainloop()
