import tkinter as tk
from tkinter import filedialog, ttk
import matplotlib

matplotlib.use('TkAgg')
from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
from matplotlib.figure import Figure
from video_game import VideoGame


class PageOne(tk.Tk):
    def __init__(self, video_game: VideoGame):
        super().__init__()  
        self.title("Video Game")
        self.video_game = video_game
        
        self.select_game = tk.StringVar(master=self)
        self.select_game.set(self.video_game.get_game_by_year(self.video_game.year[0])[0])

        self.select_platform = tk.BooleanVar(master=self)

        self.select_year = tk.IntVar(master=self)
        self.select_year.set(self.video_game.year[0])

        self.init_component()

    def init_component(self):
        #create frame
        option_frame = tk.LabelFrame(self, text="Option")
        select_frame = tk.Frame(option_frame)

        #create select game combobox
        self.select_game_combobox = ttk.Combobox(select_frame, textvariable=self.select_game, state="readonly")
        self.select_game_combobox["values"] = self.video_game.get_game_by_year(self.select_year.get())

        select_platform_checkbox = tk.Checkbutton(option_frame,
                                                  text='All platform',
                                                  variable=self.select_platform)
        
        slide_year = tk.Scale(select_frame, from_=self.video_game.year[0], to=self.video_game.year[-1],
                      variable=self.select_year, orient=tk.HORIZONTAL, command=self.update_combobox)

        graph_button = tk.Button(option_frame, text="PLOT", command=self.show_graph)

        save_button = tk.Button(option_frame, text="SAVE", command=self.save_graph)
        self.bind('<s>', lambda event: self.save_graph())
        quit_button = tk.Button(option_frame, text="QUIT", command=self.destroy)

        select_game_label = tk.Label(select_frame, text="select game:")

        option_frame.grid(row=0, column=0, sticky="news")
        select_frame.grid(row=0, column=0)

        self.select_game_combobox.grid(row=0, column=1, padx=5, pady=5)

        select_year_label = tk.Label(select_frame, text="select year:")
        slide_year.grid(row=1,column=1,sticky="EW")
        select_year_label.grid(row=1,column=0,sticky="EW")

        graph_button.grid(row=0, column=2, padx=10, pady=5)
        save_button.grid(row=0, column=3, padx=10, pady=5)
        quit_button.grid(row=0, column=4, padx=10, pady=5)

        select_platform_checkbox.grid(row=0, column=1, padx=10, pady=5)

        select_game_label.grid(row=0, column=0, pady=5)

        self.fig = Figure()
        self.axes = self.fig.add_subplot()
        self.fig.subplots_adjust(bottom=0.21)
        self.fig_canvas = FigureCanvasTkAgg(self.fig, master=self)
        self.fig_canvas.get_tk_widget().grid(row=1, column=0, sticky="NEWS", padx=5, pady=5)
        self.rowconfigure(1, weight=1)
        self.columnconfigure(0, weight=1)

    def show_graph(self):
        self.video_game.set_state(self.select_platform.get())
        self.axes.clear()
        self.video_game.game_name = self.select_game.get()
        graph = self.video_game.plot_graph(self.axes)
        self.fig_canvas.draw()

    def save_graph(self):
        file = filedialog.asksaveasfilename(title='Save File', filetypes=(("PNG file", "*.png"),))
        if file != "":
            self.fig.get_figure().savefig(file)

    def update_combobox(self,year):
        self.select_game_combobox["values"] = self.video_game.get_game_by_year(year)

    def run(self):
        self.mainloop()
