import pandas as pd
import networkx as nx
import matplotlib.pyplot as plt

# Load dataset
df = pd.read_csv('Video_Games_1.csv')

# Create a graph from the dataset using genre as nodes and number of shared publishers as edges
G = nx.Graph()
genres = set(df['Genre'])
for genre1 in genres:
    for genre2 in genres:
        if genre1 != genre2:
            publishers1 = set(df[df['Genre']==genre1]['Publisher'])
            publishers2 = set(df[df['Genre']==genre2]['Publisher'])
            shared_publishers = len(publishers1.intersection(publishers2))
            if shared_publishers > 0:
                G.add_edge(genre1, genre2, weight=shared_publishers)

# Plot the graph
pos = nx.spring_layout(G)
nx.draw_networkx(G, pos, with_labels=True, node_color='lightblue', node_size=1000, font_size=10, font_weight='bold')
labels = nx.get_edge_attributes(G,'weight')
nx.draw_networkx_edge_labels(G, pos, edge_labels=labels, font_size=8)

# Find the shortest path between two genres using breadth-first search algorithm
genre1 = 'Fighting'
genre2 = 'Sports'
path = nx.shortest_path(G, genre1, genre2, weight='weight')

# Highlight the shortest path
edges = list(zip(path, path[1:]))
nx.draw_networkx_edges(G, pos, edgelist=edges, edge_color='red', width=5)

# Show the plot
plt.show()