import pandas as pd
import matplotlib

matplotlib.use('TkAgg')
from matplotlib.figure import Figure


class VideoGame:
    def __init__(self):
        self.video_game_df = pd.read_csv("Video_Games_1.csv")

        self.game_name = ""
        self.__year = []
        self.get_year()

        self.PlotPie = PlotPie(self)
        self.AllPlatform = AllPlatform(self)
        self.NotAllPlatform = NotAllPlatform(self)
        self.__state = self.NotAllPlatform

    @property
    def state(self):
        return self.__state

    @property
    def year(self):
        return self.__year

    def get_combobox(self):
        return sorted(self.video_game_df.iloc[::]["Name"].unique().tolist())

    def get_game_df(self):
        return self.video_game_df[self.video_game_df.Name == self.game_name]
    
    def get_game_by_year(self, year):
        gameInYear = self.video_game_df[self.video_game_df.Year_of_Release == int(year)]
        return sorted(gameInYear.iloc[::]["Name"].unique().tolist())

    def get_year(self):
        for i in self.video_game_df["Year_of_Release"].dropna():
            if i not in self.year:
                self.__year.append(i)

    def set_state(self, check_state):
        if check_state:
            self.__state = self.AllPlatform
        else:
            self.__state = self.NotAllPlatform

    def plot_graph(self, ax):
        self.state.plot_graph(ax)

    def plot_pie(self, year, ax):
        self.PlotPie.plot_graph(year, ax)


class PlotPie:
    def __init__(self, video_game: VideoGame):
        self.video_game = video_game
        self.game_df = video_game.video_game_df

    def plot_graph(self, year, ax):
        df = self.game_df[self.game_df.Year_of_Release == int(year)]
        pie_graph = df["Genre"].value_counts().plot.pie(ylabel="", autopct="%1.01f%%", ax=ax)
        pie_graph.set_title("Game Genre")
        return pie_graph


class PlotBar:
    def __init__(self, video_game: VideoGame):
        self.video_game = video_game

    def plot_graph(self, ax):
        pass


class AllPlatform(PlotBar):
    def __init__(self, video_game: VideoGame):
        super().__init__(video_game)

    def plot_graph(self, ax):
        game = self.video_game.get_game_df()
        game_bar = game.plot.bar(x="Platform",
                                 y="Global_Sales",
                                 xlabel="Platform",
                                 ylabel="Global Sales in million",
                                 rot=45,
                                 ax=ax)
        return game_bar


class NotAllPlatform(PlotBar):
    def __init__(self, video_game: VideoGame):
        super().__init__(video_game)

    def plot_graph(self, ax):
        game = self.video_game.get_game_df()
        game_bar = game[["NA_Sales", "EU_Sales", "JP_Sales", "Other_Sales"]]
        game_bar = game.T["NA_Sales":"Other_Sales"]
        game_bar["Sales"] = game_bar.sum(axis=1)
        game_bar = game_bar.plot.bar(y="Sales",
                                     xlabel="Region",
                                     ylabel="Sales in million",
                                     rot=45,
                                     ax=ax)
        return game_bar
    
class Network_graph:
    def __init__(self, video_game: VideoGame):
        self.video_game = video_game
        self.game_df = video_game.video_game_df

    def plot_graph(self, year, ax):
        df = self.game_df[self.game_df.Year_of_Release == int(year)]
        pie_graph = df["Genre"].value_counts().plot.pie(ylabel="", autopct="%1.01f%%", ax=ax)
        pie_graph.set_title("Game Genre")
        return pie_graph

