import time
import tkinter as tk
from tkinter import ttk
from video_game import VideoGame, PlotPie
from program_ui import PageOne
from pie_ui import PageTwo
from network_UI import Network_UI

class VideoGameFacade:
    def __init__(self, video_game: VideoGame):
        self.video_game = video_game
        self.task_num=0

    def open_sales_rate(self):
        pg_one = PageOne(self.video_game)
        pg_one.run()

    def open_type_game(self):
        pg_two = PageTwo(self.video_game)
        pg_two.run()

    def open_network(self):
        pg_three = Network_UI(self.video_game)
        pg_three.run()

class App(tk.Tk):
    def __init__(self, facade: VideoGameFacade):
        super().__init__()
        self.facade = facade
        self.title("Video Game")
        self.geometry('250x120')

        self.init_component()

    def init_component(self):
        self.first_button = tk.Button(self, text="Sales Rate", command=self.first_command)
        self.second_button = tk.Button(self, text="Game Genre", command=self.second_command)
        self.third_button = tk.Button(self, text="Network", command=self.third_command)
        self.quit_button = tk.Button(self, text="QUIT", command=exit)

        self.first_button.pack()
        self.second_button.pack()
        self.third_button.pack()
        self.quit_button.pack()

    def first_command(self):
        self.task_num=1
        self.loading()

    def second_command(self):
        self.task_num=2
        self.loading()

    def third_command(self):
        self.task_num=3
        self.loading()


    def loading(self):
        self.first_button.config(state="disabled")
        self.second_button.config(state="disabled")
        self.third_button.config(state="disabled")
        self.quit_button.config(state="disabled")
        popup = tk.Toplevel()
        popup.geometry('200x100')
        popup.title('Loading...')
        progress_var = tk.DoubleVar()
        progress_bar = ttk.Progressbar(popup, variable=progress_var, maximum=100)
        progress_bar.pack(pady=10)
        for i in range(10):
        # Simulate a time-consuming task
            time.sleep(0.025)
            progress_var.set((i + 1) * 10)
            progress_bar.update()
        popup.destroy()

        self.first_button.config(state="normal")
        self.second_button.config(state="normal")
        self.third_button.config(state="normal")
        self.quit_button.config(state="normal")
        #after finish do task
        if self.task_num==1:
            self.facade.open_sales_rate()
        elif self.task_num==2:
            self.facade.open_type_game()
        elif self.task_num==3:
            self.facade.open_network()

    def do_task(self):
        self.init_component()

    def run(self):
        self.mainloop()